0.9.9 API documentation: projection.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
projection.hpp File Reference

GLM_GTX_projection More...

Go to the source code of this file.

## Functions
template<typename genType >
GLM_FUNC_DECL genType | proj (genType const &x, genType const &Normal)
| Projects x on Normal. More...

## Detailed Description

GLM_GTX_projection

See also
  Core features (dependence)

Definition in file projection.hpp.